<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>Application</name>
    <message>
        <location filename="../reader/Application.cpp" line="39"/>
        <source>Document Viewer</source>
        <translation>Pregledovalnik dokumentov</translation>
    </message>
    <message>
        <location filename="../reader/Application.cpp" line="40"/>
        <source>Document Viewer is a tool for reading document files, supporting PDF, DJVU, DOCX etc.</source>
        <translation>Pregledovalnik dokumentov je orodje za branje dokumentov, ki podpira PDF, DJVU, DOCX itd.</translation>
    </message>
</context>
<context>
    <name>AttrScrollWidget</name>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="46"/>
        <source>Location</source>
        <translation>Lokacija</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="47"/>
        <source>Subject</source>
        <translation>Subjekt</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="48"/>
        <source>Author</source>
        <translation>Avtor</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="49"/>
        <source>Keywords</source>
        <translation>Ključne besede</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="50"/>
        <source>Producer</source>
        <translation>Producent</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="51"/>
        <source>Creator</source>
        <translation>Ustvarjalec</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="52"/>
        <source>Time created</source>
        <translation>Ustvarjeno</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="53"/>
        <source>Time modified</source>
        <translation>Spremenjeno</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="54"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="55"/>
        <source>Pages</source>
        <translation>Strani</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="56"/>
        <source>Optimized</source>
        <translation>Optimatizirano</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="57"/>
        <source>Security</source>
        <translation>Varnost</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="59"/>
        <source>Page size</source>
        <translation>Velikost strani</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="60"/>
        <source>File size</source>
        <translation>Velikost datoteke</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="65"/>
        <source>Basic info</source>
        <translation>Osnovni podatki</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="85"/>
        <source>Unknown</source>
        <translation>Neznano</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <location filename="../reader/widgets/AttrScrollWidget.cpp" line="127"/>
        <source>No</source>
        <translation>Ne</translation>
    </message>
</context>
<context>
    <name>BookMarkWidget</name>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="64"/>
        <source>Add bookmark</source>
        <translation>Dodaj zaznamek</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/BookMarkWidget.cpp" line="220"/>
        <source>Are you sure you want to delete all bookmarks?</source>
        <translation>Ali ste prepričani, da želite odstraniti vse zaznamke?</translation>
    </message>
</context>
<context>
    <name>BrowserMenu</name>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="39"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="52"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="56"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="43"/>
        <source>Remove annotation</source>
        <translation>Odstrani opombe</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="44"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="73"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="134"/>
        <source>Add annotation</source>
        <translation>Dodaj opombo</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="47"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="77"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="85"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="129"/>
        <source>Remove bookmark</source>
        <translation>Odstrani zaznamek</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="49"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="79"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="87"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="131"/>
        <source>Add bookmark</source>
        <translation>Dodaj zaznamek</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="60"/>
        <source>Highlight</source>
        <translation>Osvetli</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="69"/>
        <source>Remove highlight</source>
        <translation>Odstrani osvetlitev</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="81"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="124"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="92"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="140"/>
        <source>Exit fullscreen</source>
        <translation>Zapri celozaslonski način</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="94"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="142"/>
        <source>Fullscreen</source>
        <translation>Celozaslonsko</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="97"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="145"/>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="100"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="148"/>
        <source>First page</source>
        <translation>Prva stran</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="101"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="149"/>
        <source>Previous page</source>
        <translation>Prejšnja stran</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="107"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="155"/>
        <source>Next page</source>
        <translation>Naslednja stran</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="108"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="156"/>
        <source>Last page</source>
        <translation>Zadnja stran</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="116"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="164"/>
        <source>Rotate left</source>
        <translation>Obrni levo</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="117"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="165"/>
        <source>Rotate right</source>
        <translation>Obrni desno</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="120"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="168"/>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <location filename="../reader/browser/BrowserMenu.cpp" line="121"/>
        <location filename="../reader/browser/BrowserMenu.cpp" line="169"/>
        <source>Document info</source>
        <translation>Podatki o dokumentu</translation>
    </message>
</context>
<context>
    <name>Central</name>
    <message>
        <location filename="../reader/uiframe/Central.cpp" line="145"/>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
</context>
<context>
    <name>CentralDocPage</name>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="166"/>
        <source>The format is not supported</source>
        <translation>Format ni podprt</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="208"/>
        <source>Open failed</source>
        <translation>Odpiranje ni uspelo</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="210"/>
        <source>Please check if the file is damaged</source>
        <translation>Preverite ali datoteka ni poškodovana</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="212"/>
        <source>Conversion failed, please check if the file is damaged</source>
        <translation>Pretvorba ni uspela. Preverite ali datoteka ni poškodovana</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="420"/>
        <source>Save failed</source>
        <translation>Neuspešno shranjevanje</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="426"/>
        <source>Saved successfully</source>
        <translation>Uspešno shranjeno</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="444"/>
        <source>Save as</source>
        <translation>Shrani kot</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="453"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="463"/>
        <source>Invalid file name</source>
        <translation>Neveljavno ime datoteke</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="455"/>
        <location filename="../reader/uiframe/CentralDocPage.cpp" line="465"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>V redu</translation>
    </message>
</context>
<context>
    <name>CentralNavPage</name>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="35"/>
        <source>Drag documents here</source>
        <translation>Povlecite dokumente sem</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="41"/>
        <source>Format supported: %1</source>
        <translation>Podprti format: %1</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/CentralNavPage.cpp" line="47"/>
        <source>Select File</source>
        <translation>Izberite datoteko</translation>
    </message>
</context>
<context>
    <name>DocSheet</name>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="327"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="355"/>
        <source>The bookmark has been removed</source>
        <translation>Zaznamek je bil odstranjen</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="528"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="543"/>
        <source>Please select the text</source>
        <translation>Izberite besedilo</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/DocSheet.cpp" line="593"/>
        <location filename="../reader/uiframe/DocSheet.cpp" line="602"/>
        <source>The annotation has been removed</source>
        <translation>Opomba je bila odstranjena</translation>
    </message>
</context>
<context>
    <name>EncryptionPage</name>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="50"/>
        <source>Encrypted file, please enter the password</source>
        <translation>Šifirirana datoreka, vnesite geslo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="56"/>
        <source>Password</source>
        <translation>Geslo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="61"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>V redu</translation>
    </message>
    <message>
        <location filename="../reader/widgets/EncryptionPage.cpp" line="105"/>
        <source>Wrong password</source>
        <translation>Napačno geslo</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="125"/>
        <source>Previous</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/FindWidget.cpp" line="133"/>
        <source>Next</source>
        <translation>Naprej</translation>
    </message>
</context>
<context>
    <name>HandleMenu</name>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="35"/>
        <source>Select Text</source>
        <translation>Izberi besedilo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/HandleMenu.cpp" line="43"/>
        <source>Hand Tool</source>
        <translation>Ročno orodje</translation>
    </message>
</context>
<context>
    <name>NotesWidget</name>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="67"/>
        <source>Add annotation</source>
        <translation>Dodaj opombo</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/NotesWidget.cpp" line="189"/>
        <source>Are you sure you want to delete all annotations?</source>
        <translation>Želite res izbrisati vse opombe?</translation>
    </message>
</context>
<context>
    <name>PagingWidget</name>
    <message>
        <location filename="../reader/widgets/PagingWidget.cpp" line="212"/>
        <source>Invalid page number</source>
        <translation>Napačna številka strani</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../reader/widgets/ProgressDialog.cpp" line="18"/>
        <source>Converting</source>
        <translation>Pretvarjanje</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../reader/app/DBusObject.cpp" line="103"/>
        <source>Document not saved</source>
        <translation>Dokument ni shranjen</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="35"/>
        <source>Save the changes to &quot;%1&quot;?</source>
        <translation>Sharnim spremembe v &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="37"/>
        <source>Discard</source>
        <comment>button</comment>
        <translation>Opusti</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="38"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SaveDialog.cpp" line="50"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ScaleMenu</name>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="35"/>
        <source>Two-Page View</source>
        <translation>Prikaz dveh strani</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="36"/>
        <source>1:1 size</source>
        <translation>razmerje 1:1</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="37"/>
        <source>Fit Page</source>
        <translation>Prilagodi strani</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="38"/>
        <source>Fit Height</source>
        <translation>Prilagodi višini</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ScaleMenu.cpp" line="39"/>
        <source>Fit Width</source>
        <translation>Prilagodi širini</translation>
    </message>
</context>
<context>
    <name>SearchResWidget</name>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="60"/>
        <source>No search results</source>
        <translation>Ni rezultatov iskanja</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SearchResWidget.cpp" line="109"/>
        <source>%1 items found</source>
        <translation>Najdenih predmetov: %1</translation>
    </message>
</context>
<context>
    <name>SecurityDialog</name>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="72"/>
        <source>This document is trying to connect to:</source>
        <translation>Ta dokument se skuša povezati s:</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="73"/>
        <source>If you trust the website, click Allow, otherwise click Block.</source>
        <translation>Če zaupate tej spletni strani, kliknite na Dovoli, sicer na Blokiraj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="76"/>
        <source>Block</source>
        <comment>button</comment>
        <translation>Blokiraj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/SecurityDialog.cpp" line="77"/>
        <source>Allow</source>
        <comment>button</comment>
        <translation>Dovoli</translation>
    </message>
</context>
<context>
    <name>SheetSidebar</name>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="84"/>
        <source>Thumbnails</source>
        <translation>Predogledne sličice</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="99"/>
        <source>Catalog</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="112"/>
        <source>Bookmarks</source>
        <translation>Zaznamki</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SheetSidebar.cpp" line="127"/>
        <source>Annotations</source>
        <translation>Opombe</translation>
    </message>
</context>
<context>
    <name>ShortCutShow</name>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="58"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="79"/>
        <source>Files</source>
        <translation>Datoteke</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="100"/>
        <source>Display</source>
        <translation>Prikaz</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="120"/>
        <source>Tools</source>
        <translation>Orodja</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Exit</source>
        <translation>Izhod</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page up</source>
        <translation>Stran gor</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Page down</source>
        <translation>Stran dol</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom in</source>
        <translation>Približaj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="203"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
        <source>Zoom out</source>
        <translation>Oddalji</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <source>Zoom in/Zoom out</source>
        <translation>Približaj/oddalji</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="235"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Save as</source>
        <translation>Shrani kot</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="194"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="201"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="243"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Thumbnails</source>
        <translation>Predogledne sličice</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>1:1 size</source>
        <translation>razmerje 1:1</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="236"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit height</source>
        <translation>Prilagodi višino</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="195"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Fit width</source>
        <translation>Prilagodi širino</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate left</source>
        <translation>Obrni levo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="202"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="244"/>
        <source>Rotate right</source>
        <translation>Obrni desno</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Select text</source>
        <translation>Izberi besedilo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="237"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Hand tool</source>
        <translation>Ročno orodje</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="196"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add bookmark</source>
        <translation>Dodaj zaznamek</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Magnifier</source>
        <translation>Povečalo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>Celozaslonsko</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="197"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Cut</source>
        <translation>Izreži</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="239"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Paste</source>
        <translation>Prilepi</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Undo</source>
        <translation>Razveljavi</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="206"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="248"/>
        <source>Select all</source>
        <translation>Izberi vse</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="198"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="200"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="240"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="242"/>
        <source>Display shortcuts</source>
        <translation>Prikaži bljižnice</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Add annotation</source>
        <translation>Dodaj opombo</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="204"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="238"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="246"/>
        <source>Highlight</source>
        <translation>Osvetli</translation>
    </message>
    <message>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="205"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
        <location filename="../reader/widgets/ShortCutShow.cpp" line="247"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
</context>
<context>
    <name>SideBarImageListView</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="194"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="199"/>
        <source>Remove annotation</source>
        <translation>Odstrani opombe</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="204"/>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="223"/>
        <source>Remove all</source>
        <translation>Odstrani vse</translation>
    </message>
    <message>
        <location filename="../reader/sidebar/SideBarImageListview.cpp" line="218"/>
        <source>Remove bookmark</source>
        <translation>Odstrani zaznamek</translation>
    </message>
</context>
<context>
    <name>SideBarImageViewModel</name>
    <message>
        <location filename="../reader/sidebar/SideBarImageViewModel.cpp" line="135"/>
        <source>Page %1</source>
        <translation>Stran %1</translation>
    </message>
</context>
<context>
    <name>SlidePlayWidget</name>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
        <source>It is the first page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
        <source>It is the last page</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleMenu</name>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New window</source>
        <translation>Novo okno</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="29"/>
        <source>New tab</source>
        <translation>Nov zavihek</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="110"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="39"/>
        <source>Save as</source>
        <translation>Shrani kot</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Display in file manager</source>
        <translation>Prikaži v upravljaniku datotek</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="44"/>
        <source>Magnifer</source>
        <translation>Povečalo</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="50"/>
        <source>Tools</source>
        <translation>Orodja</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Search</source>
        <translation>Iskanje</translation>
    </message>
    <message>
        <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <location filename="../reader/uiframe/TitleWidget.cpp" line="37"/>
        <source>Thumbnails</source>
        <translation>Predogledne sličice</translation>
    </message>
</context>
<context>
    <name>TransparentTextEdit</name>
    <message>
        <location filename="../reader/widgets/TransparentTextEdit.cpp" line="82"/>
        <source>Input limit reached</source>
        <translation>Vhodna omejitev je bila dosežena</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../reader/main.cpp" line="40"/>
        <source>Document File Path.</source>
        <translation>Pot do dokumenta.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="41"/>
        <location filename="../reader/main.cpp" line="45"/>
        <source>FilePath</source>
        <translation>PotDokumenta</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="44"/>
        <source>ThumbnailPath Path.</source>
        <translation>PotPredogledne pot.</translation>
    </message>
    <message>
        <location filename="../reader/main.cpp" line="49"/>
        <source>Generate thumbnail.</source>
        <translation>Ustvari predogledno sličico.</translation>
    </message>
</context>
</TS>